@@ -1,5 +1,5 @@
-import asyncio
 from abc import abstractmethod, ABC
+from multiprocessing.pool import ThreadPool
 
 import yaml
 
@@ -74,14 +74,13 @@ class DumpDashboardsUseCase(DumpMonitorUseCase):
         if not ok:
             return ok, res
 
+        ok, teams = self._monitor.get_teams()
+        team_match = {team["id"]: team["name"] for team in teams} if ok else {}
         dashboards = []
-        tasks = []
         errors = []
-        for i in res["dashboards"]:
-            tasks.append(asyncio.get_event_loop().run_in_executor(None, self._monitor.get_dashboard, i["id"]))
-
-        for ok, data in asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks)):
+        for ok, data in ThreadPool().map(self._monitor.get_dashboard, (db["id"] for db in res["dashboards"])):
             if ok:
+                data["dashboard"]["teamName"] = team_match.get(data["dashboard"].get("teamId", 0))
                 dashboards.append(data["dashboard"])
             else:
                 errors.append(data)
@@ -207,12 +206,8 @@ class DumpUserCreatedRulesUseCase(DumpSecureUseCase):
             return ok, res
 
         rules = []
-        tasks = []
         errors = []
-        for i in res:
-            tasks.append(asyncio.get_event_loop().run_in_executor(None, self._secure.get_rule_id, i["id"]))
-
-        for ok, data in asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks)):
+        for ok, data in ThreadPool().map(self._secure.get_rule_id, (i["id"] for i in res)):
             if ok:
                 rules.append(data)
             else:
@@ -290,12 +285,8 @@ class DumpUserCreatedFalcoMacrosUseCase(DumpSecureUseCase):
             return ok, res
 
         falco_macros = []
-        tasks = []
         errors = []
-        for i in res:
-            tasks.append(asyncio.get_event_loop().run_in_executor(None, self._secure.get_falco_macro_id, i['id']))
-
-        for ok, data in asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks)):
+        for ok, data in ThreadPool().map(self._secure.get_falco_macro_id, (i['id'] for i in res)):
             if ok:
                 falco_macros.append(data)
             else:
@@ -349,12 +340,8 @@ class DumpUserCreatedFalcoListsUseCase(DumpSecureUseCase):
             return ok, res
 
         falco_lists = []
-        tasks = []
         errors = []
-        for i in res:
-            tasks.append(asyncio.get_event_loop().run_in_executor(None, self._secure.get_falco_list_id, i["id"]))
-
-        for ok, data in asyncio.get_event_loop().run_until_complete(asyncio.gather(*tasks)):
+        for ok, data in ThreadPool().map(self._secure.get_falco_list_id, (i["id"] for i in res)):
             if ok:
                 falco_lists.append(data)
             else:
