@@ -39,6 +39,8 @@ class RestoreUseCase(ABC):
 
     def _load_data_from_repo(self, kind):
         file_data = self._formatter(self._repository.read())
+        if file_data is None:
+            return []
         file_data = [data["spec"] for data in file_data if data["kind"] == kind]
         return file_data
 
